@@ -52,6 +52,14 @@ def log_error(msg):
         log.error(msg)
 
 
+class Emoji(str):
+    """
+    Wrap emojis in this subclass so we can select only the emojis or only the detail sections
+    when displaying messages in Slack.
+    """
+    pass
+
+
 class ButtonPress:
     def __init__(self, event):
         self.event = event
@@ -444,7 +452,7 @@ class SlackDeploymentProcess(DeploymentProcess, abc.ABC):
                     buttonpress = event_to_buttonpress(event)
                     if self.is_relevant_buttonpress(buttonpress):
                         self.update_slack_thread(
-                            f'{buttonpress.username} pressed {buttonpress.action}',
+                            f'<@{buttonpress.username}> pressed {buttonpress.action}',
                         )
                         self.last_action = buttonpress.action
 
